@@ -3,7 +3,7 @@ use std::fmt::Debug;
 
 /// Handles a given [`libcnb::Error`] in a consistent, Heroku specific, style.
 ///
-/// This function is intended to be used inside [`libcnb::Buildpack::handle_error`].
+/// This function is intended to be used inside [`libcnb::Buildpack::on_error`].
 ///
 /// It outputs generic libcnb errors in a consistent style using the [logging functions](log_error) from this
 /// crate. Buildpack specific errors are handled by the passed custom handler.
@@ -14,7 +14,7 @@ use std::fmt::Debug;
 /// use libcnb::Buildpack;
 /// use libcnb::detect::{DetectContext, DetectResult};
 /// use libcnb::generic::{GenericMetadata, GenericPlatform};
-/// use libherokubuildpack::{handle_error_heroku, log_error};
+/// use libherokubuildpack::{on_error_heroku, log_error};
 ///
 /// #[derive(Debug)]
 /// enum FooBuildpackError {
@@ -22,14 +22,14 @@ use std::fmt::Debug;
 ///     InvalidFooDescriptorToml
 /// }
 ///
-/// fn handle_foo_buildpack_error(e: FooBuildpackError) -> i32 {
+/// fn on_foo_buildpack_error(e: FooBuildpackError) -> i32 {
 ///     match e {
 ///         FooBuildpackError::InvalidFooDescriptorToml => {
 ///             log_error("Invalid foo.toml", "Your app's foo.toml is invalid!");
 ///             23
 ///         }
 ///         FooBuildpackError::CannotExecuteFooBuildTool(inner) => {
-///             log_error("Cannot execute foo buildtool", format!("Cause: {}", &inner));
+///             log_error("Cannot execute foo build tool", format!("Cause: {}", &inner));
 ///             42
 ///         }
 ///     }
@@ -51,12 +51,12 @@ use std::fmt::Debug;
 ///     #     unimplemented!()
 ///     # }
 ///
-///     fn handle_error(&self, error: libcnb::Error<Self::Error>) -> i32 {
-///         handle_error_heroku(handle_foo_buildpack_error, error)
+///     fn on_error(&self, error: libcnb::Error<Self::Error>) -> i32 {
+///         on_error_heroku(on_foo_buildpack_error, error)
 ///     }
 /// }
 /// ```
-pub fn handle_error_heroku<F, E>(f: F, error: libcnb::Error<E>) -> i32
+pub fn on_error_heroku<F, E>(f: F, error: libcnb::Error<E>) -> i32
 where
     E: Debug,
     F: Fn(E) -> i32,
@@ -74,7 +74,7 @@ const INTERNAL_BUILDPACK_ERROR_EXIT_CODE: i32 = 100;
 
 #[cfg(test)]
 mod test {
-    use super::handle_error_heroku;
+    use super::*;
 
     #[test]
     fn test() {
@@ -83,6 +83,6 @@ mod test {
 
         let error = libcnb::Error::BuildpackError("()");
 
-        assert_eq!(handle_error_heroku(handler, error), base_value * 2);
+        assert_eq!(on_error_heroku(handler, error), base_value * 2);
     }
 }
